pub struct ToolInvocation {
pub tool_name: String,
pub trace_id: String,
pub started_at: DateTime<Utc>,
pub finished_at: DateTime<Utc>,
}Expand description
Record of a single MCP tool invocation used for provenance and replay.
Fields
tool_name: Stringtrace_id: Stringstarted_at: DateTime<Utc>finished_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for ToolInvocation
impl Clone for ToolInvocation
Sourcefn clone(&self) -> ToolInvocation
fn clone(&self) -> ToolInvocation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ToolInvocation
impl Debug for ToolInvocation
Sourceimpl<'de> Deserialize<'de> for ToolInvocation
impl<'de> Deserialize<'de> for ToolInvocation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ToolInvocation
Sourceimpl JsonSchema for ToolInvocation
impl JsonSchema for ToolInvocation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ToolInvocation
impl PartialEq for ToolInvocation
Sourcefn eq(&self, other: &ToolInvocation) -> bool
fn eq(&self, other: &ToolInvocation) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ToolInvocation
impl Serialize for ToolInvocation
impl StructuralPartialEq for ToolInvocation