pub struct SemanticEmbeddingProviderFactoryConfig<'a> {
pub provider: SemanticRuntimeProvider,
pub model: &'a str,
pub credentials: &'a SemanticRuntimeCredentials,
pub local_artifact_policy: LocalArtifactPolicy,
}Expand description
Inputs required to construct a semantic embedding provider for indexing or recall.
Fields
provider: SemanticRuntimeProvidermodel: &'a strcredentials: &'a SemanticRuntimeCredentialslocal_artifact_policy: LocalArtifactPolicyTrait Implementations
Sourceimpl<'a> Clone for SemanticEmbeddingProviderFactoryConfig<'a>
impl<'a> Clone for SemanticEmbeddingProviderFactoryConfig<'a>
Sourcefn clone(&self) -> SemanticEmbeddingProviderFactoryConfig<'a>
fn clone(&self) -> SemanticEmbeddingProviderFactoryConfig<'a>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a> Debug for SemanticEmbeddingProviderFactoryConfig<'a>
impl<'a> Debug for SemanticEmbeddingProviderFactoryConfig<'a>
impl<'a> Eq for SemanticEmbeddingProviderFactoryConfig<'a>
Sourceimpl<'a> PartialEq for SemanticEmbeddingProviderFactoryConfig<'a>
impl<'a> PartialEq for SemanticEmbeddingProviderFactoryConfig<'a>
Sourcefn eq(&self, other: &SemanticEmbeddingProviderFactoryConfig<'a>) -> bool
fn eq(&self, other: &SemanticEmbeddingProviderFactoryConfig<'a>) -> bool
Tests for
self and other values to be equal, and is used by ==.impl<'a> StructuralPartialEq for SemanticEmbeddingProviderFactoryConfig<'a>