pub enum ScipIngestError {
InvalidInput {
diagnostic: ScipInvalidInputDiagnostic,
},
ResourceBudgetExceeded {
diagnostic: ScipResourceBudgetDiagnostic,
},
}Expand description
Failure modes for SCIP ingest bounded by input validation and resource budgets.
Variants
InvalidInput
Fields

diagnostic: ScipInvalidInputDiagnosticResourceBudgetExceeded
Fields

diagnostic: ScipResourceBudgetDiagnosticTrait Implementations
Sourceimpl Clone for ScipIngestError
impl Clone for ScipIngestError
Sourcefn clone(&self) -> ScipIngestError
fn clone(&self) -> ScipIngestError
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScipIngestError
impl Debug for ScipIngestError
Sourceimpl Display for ScipIngestError
impl Display for ScipIngestError
impl Eq for ScipIngestError
Sourceimpl Error for ScipIngestError
impl Error for ScipIngestError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl PartialEq for ScipIngestError
impl PartialEq for ScipIngestError
Sourcefn eq(&self, other: &ScipIngestError) -> bool
fn eq(&self, other: &ScipIngestError) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ScipIngestError