pub struct SyntaxTreeInspectionNode {
pub kind: String,
pub named: bool,
pub span: SourceSpan,
pub excerpt: String,
}Expand description
One syntax-tree node with kind metadata and a bounded source excerpt.
Fields
kind: Stringnamed: boolspan: SourceSpanexcerpt: StringTrait Implementations
Sourceimpl Clone for SyntaxTreeInspectionNode
impl Clone for SyntaxTreeInspectionNode
Sourcefn clone(&self) -> SyntaxTreeInspectionNode
fn clone(&self) -> SyntaxTreeInspectionNode
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SyntaxTreeInspectionNode
impl Debug for SyntaxTreeInspectionNode
Sourceimpl<'de> Deserialize<'de> for SyntaxTreeInspectionNode
impl<'de> Deserialize<'de> for SyntaxTreeInspectionNode
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SyntaxTreeInspectionNode
Sourceimpl PartialEq for SyntaxTreeInspectionNode
impl PartialEq for SyntaxTreeInspectionNode
Sourcefn eq(&self, other: &SyntaxTreeInspectionNode) -> bool
fn eq(&self, other: &SyntaxTreeInspectionNode) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SyntaxTreeInspectionNode
impl Serialize for SyntaxTreeInspectionNode
impl StructuralPartialEq for SyntaxTreeInspectionNode