pub struct ExploreMetadata {
pub lossy_utf8: bool,
pub effective_context_lines: usize,
pub effective_max_matches: usize,
pub context_efficiency: Option<ContextEfficiencyMetadata>,
}Expand description
Explorer execution metadata including effective limits and optional context-efficiency stats.
Fields
lossy_utf8: booleffective_context_lines: usizeeffective_max_matches: usizecontext_efficiency: Option<ContextEfficiencyMetadata>Trait Implementations
Sourceimpl Clone for ExploreMetadata
impl Clone for ExploreMetadata
Sourcefn clone(&self) -> ExploreMetadata
fn clone(&self) -> ExploreMetadata
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExploreMetadata
impl Debug for ExploreMetadata
Sourceimpl<'de> Deserialize<'de> for ExploreMetadata
impl<'de> Deserialize<'de> for ExploreMetadata
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ExploreMetadata
impl JsonSchema for ExploreMetadata
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExploreMetadata
impl PartialEq for ExploreMetadata
Sourcefn eq(&self, other: &ExploreMetadata) -> bool
fn eq(&self, other: &ExploreMetadata) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ExploreMetadata
impl Serialize for ExploreMetadata
impl StructuralPartialEq for ExploreMetadata