pub struct ImplementationMatch {Show 14 fields
pub match_id: Option<String>,
pub stable_symbol_id: Option<String>,
pub symbol: String,
pub kind: Option<String>,
pub repository_id: String,
pub path: String,
pub line: usize,
pub column: usize,
pub relation: Option<String>,
pub container: Option<String>,
pub signature: Option<String>,
pub precision: Option<String>,
pub fallback_reason: Option<String>,
pub follow_up_structural: Vec<GeneratedStructuralFollowUp>,
}Expand description
One implementation or override location for a resolved symbol target.
Fields
match_id: Option<String>stable_symbol_id: Option<String>symbol: Stringkind: Option<String>repository_id: Stringpath: Stringline: usizecolumn: usizerelation: Option<String>container: Option<String>signature: Option<String>precision: Option<String>fallback_reason: Option<String>follow_up_structural: Vec<GeneratedStructuralFollowUp>Trait Implementations
Sourceimpl Clone for ImplementationMatch
impl Clone for ImplementationMatch
Sourcefn clone(&self) -> ImplementationMatch
fn clone(&self) -> ImplementationMatch
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ImplementationMatch
impl Debug for ImplementationMatch
Sourceimpl<'de> Deserialize<'de> for ImplementationMatch
impl<'de> Deserialize<'de> for ImplementationMatch
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ImplementationMatch
impl JsonSchema for ImplementationMatch
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ImplementationMatch
impl RefUnwindSafe for ImplementationMatch
impl Send for ImplementationMatch
impl Sync for ImplementationMatch
impl Unpin for ImplementationMatch
impl UnsafeUnpin for ImplementationMatch
impl UnwindSafe for ImplementationMatch