pub struct WorkspacePrepareResponse {
pub repository: RepositorySummary,
pub resolved_from: Option<String>,
pub resolution: Option<WorkspaceResolveMode>,
pub session_default: bool,
pub storage: WorkspaceStorageSummary,
}Expand description
Response from workspace_prepare.
Fields
repository: RepositorySummaryresolved_from: Option<String>resolution: Option<WorkspaceResolveMode>session_default: boolstorage: WorkspaceStorageSummaryTrait Implementations
Sourceimpl Clone for WorkspacePrepareResponse
impl Clone for WorkspacePrepareResponse
Sourcefn clone(&self) -> WorkspacePrepareResponse
fn clone(&self) -> WorkspacePrepareResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WorkspacePrepareResponse
impl Debug for WorkspacePrepareResponse
Sourceimpl<'de> Deserialize<'de> for WorkspacePrepareResponse
impl<'de> Deserialize<'de> for WorkspacePrepareResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for WorkspacePrepareResponse
impl JsonSchema for WorkspacePrepareResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for WorkspacePrepareResponse
impl RefUnwindSafe for WorkspacePrepareResponse
impl Send for WorkspacePrepareResponse
impl Sync for WorkspacePrepareResponse
impl Unpin for WorkspacePrepareResponse
impl UnsafeUnpin for WorkspacePrepareResponse
impl UnwindSafe for WorkspacePrepareResponse