pub struct SemanticChunkEmbeddingProjection {
pub chunk_id: String,
pub repository_id: String,
pub snapshot_id: String,
pub path: String,
pub language: String,
pub start_line: usize,
pub end_line: usize,
pub embedding: Vec<f32>,
}Expand description
Semantic chunk projection containing path coordinates and embedding vector only.
Fields
chunk_id: Stringrepository_id: Stringsnapshot_id: Stringpath: Stringlanguage: Stringstart_line: usizeend_line: usizeembedding: Vec<f32>Trait Implementations
Sourceimpl Clone for SemanticChunkEmbeddingProjection
impl Clone for SemanticChunkEmbeddingProjection
Sourcefn clone(&self) -> SemanticChunkEmbeddingProjection
fn clone(&self) -> SemanticChunkEmbeddingProjection
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for SemanticChunkEmbeddingProjection
impl PartialEq for SemanticChunkEmbeddingProjection
Sourcefn eq(&self, other: &SemanticChunkEmbeddingProjection) -> bool
fn eq(&self, other: &SemanticChunkEmbeddingProjection) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SemanticChunkEmbeddingProjection